import { bodySizes, fontWeights, headlineSizes, lineHeights, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSansSizes, titlepieceSizes } from "./typography/data";
type ScaleUnit = 'rem' | 'px';
type LineHeight = keyof typeof lineHeights;
type FontWeight = 'light' | 'regular' | 'medium' | 'bold';
type FontStyle = 'normal' | 'italic';
type FontWeightDefinition = {
    hasItalic: boolean;
};
type Option<A> = A | null;
type TypographyStyles<Unit extends ScaleUnit = ScaleUnit> = {
    fontFamily: string;
    fontSize: Unit extends 'px' ? number : `${number}rem`;
    lineHeight: string | number;
    fontWeight?: typeof fontWeights[keyof typeof fontWeights] | FontWeight;
    fontStyle?: 'normal' | 'italic';
    textDecorationThickness?: number;
};
/** @deprecated will be removed in the next major version */
type TypographySizes = {
    [key in string]: number;
};
type TitlepieceSizes = typeof titlepieceSizes | typeof remTitlepieceSizes;
type HeadlineSizes = typeof headlineSizes | typeof remHeadlineSizes;
type BodySizes = typeof bodySizes | typeof remBodySizes;
type TextSansSizes = typeof textSansSizes | typeof remTextSansSizes;
type Categories = {
    titlepiece: TitlepieceSizes;
    headline: HeadlineSizes;
    body: BodySizes;
    textSans: TextSansSizes;
};
type Category = keyof Categories;
type AvailableFontsMapping = {
    [cat in Category]: {
        [fontWeight in FontWeight]?: FontWeightDefinition;
    };
};
type Fs = <Category extends keyof Categories, Level extends keyof Categories[Category]>(category: Category) => (level: Level, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}
export { ScaleUnit, LineHeight, FontWeight, FontStyle, FontWeightDefinition, Option, TypographyStyles, TypographySizes, TitlepieceSizes, HeadlineSizes, BodySizes, TextSansSizes, Category, AvailableFontsMapping, Fs, FontScaleFunction, FontScaleFunctionStr, FontScaleArgs };
